import React, { useState } from "react";
import * as d3 from 'd3';

const Bar = ({ data, width, height }: any) => {
    const [found, setFound] = useState<boolean>(false);

    React.useEffect(() => {
        if (data.length === 0) setFound(false);
        else setFound(true);
        const margin = { top: 20, right: 20, bottom: 50, left: 70 };
        const w = width - margin.left - margin.right;
        const h = height - margin.top - margin.bottom;

        const svg = d3
            .select("#piechart")
            .append("svg")
            .attr("width", width)
            .attr("height", height)
            .append("g")
            .attr("transform", `translate(${margin.left}, ${margin.top})`);

        const everything = svg.selectAll("*");
        everything.remove();

        // Set up scales
        const xScale = d3
            .scaleBand()
            .domain(data.map((d: any, i: any) => i))
            .range([0, width])
            .padding(0.1);

        const yScale = d3
            .scaleLinear()
            .domain([0, d3.max(data)])
            .range([height, 0]);

        const X = d3
            .axisBottom(xScale)
            .ticks(5);

        const Y = d3
            .axisLeft(yScale)
            .ticks(5);

        svg
            .append('g')
            .attr('transform', `translate(0, ${height})`)
            .call(X);

        svg
            .append('g')
            .call(Y);

        // Create bars
        svg
            .selectAll('.bar')
            .data(data)
            .join('rect')
            .attr('class', 'bar')
            .attr('x', (d: any, i: any) => xScale(i))
            .attr('y', (d: any) => yScale(d))
            .attr('width', xScale.bandwidth())
            .attr('height', (d: any) => height - yScale(d));

    }, [data, width, height]);

    return (
        <>
            {found ? <div id="barchart"></div> : <h2>Erreur, aucune donnée trouvée !</h2>}
        </>
    );
};

export default function BarChart(props: any) {

    return (
        <div>
            <h1>Affichage des données par un diagramme à barre</h1>
            <div style={{ marginLeft: 10, }}>
                <Bar data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}