import React, { useEffect, useRef } from "react";
import * as d3 from 'd3';

interface DataPoint {
    x: number;
    y: number;
}

const Line = ({ data, width, height }: any) => {
    const svgRef: any = useRef<SVGSVGElement>(null);

    useEffect(() => {
        const margin = { top: 20, right: 20, bottom: 50, left: 70 };
        const w = width - margin.left - margin.right;
        const h = height - margin.top - margin.bottom;

        const svg = d3
            .select(svgRef.current)
            .attr("transform", `translate(${margin.left}, ${margin.top})`);

        const everything = svg.selectAll("*");
        everything.remove();

        const xDomain: any[] = d3.extent(data, (d: any) => d.date);
        const X = d3.scaleTime().domain(xDomain).range([0, w]);
        svg
            .append('g')
            .attr("transform", `translate(0, ${h})`)
            .call(d3.axisBottom(X).ticks(5));

        const yDomain: any[] = d3.extent(data, (d: any) => d.averagePrice);
        const Y = d3.scaleLinear().domain(yDomain).range([h, 0]);
        svg
            .append("g")
            .call(d3.axisLeft(Y).ticks(4).tickSize(-w));

        const line = d3
            .line<DataPoint>()
            .x((d: any) => X(d.date))
            .y((d: any) => Y(d.averagePrice));

        svg
            .append("path")
            .data([data])
            .attr("class", "line")
            .attr("fill", "none")
            .attr("stroke", "steelblue")
            .attr("stroke-width", 1.5)
            .attr("d", line);

    }, [data, height, width]);

    return (
        <svg ref={svgRef} width={width} height={height} />
    );
};

export default function TimeSeries(props: any) {

    return (
        <div>
            <h1>Affichage des données par une série temporelle</h1>
            <Line data={props.data} width={props.width} height={props.height} />
        </div>
    )
}